Oral Argument Recordings

| ## Seventh Circuit Court of Appeals Public Access to Oral Argument recordings |  |

Search by Case Number:
year | number (or initial portion) |  |

Recent Arguments:

Oral Argument Recordings

Case # | Caption | Case Type | Date Argued | Description
--- | --- | --- | --- | ---
14-1560 | USA v. Dione Joyce | criminal | 07/09/2014 | oral argument
14-1001 | USA v. Carlos Ponce-Perez | criminal | 07/09/2014 | oral argument
14-1176 | Yi Wang v. Eric Holder, Jr. | agency | 07/08/2014 | oral argument
14-1633 | USA v. Darius Johnson | criminal | 07/08/2014 | oral argument
14-1825 | Lu Junhong v. Boeing Company | civil | 06/26/2014 | oral argument
14-1120 | USA v. James Hardimon | criminal | 06/11/2014 | oral argument
14-1405 | USA v. Lisa Luckett | criminal | 06/11/2014 | oral argument
14-1013 | USA v. Royce Spann | criminal | 06/11/2014 | oral argument
14-1284 | USA v. Adel Daoud | criminal | 06/09/2014 | oral argument
14-1273 | USA v. Mansa Baptist | criminal | 06/06/2014 | oral argument
14-1532 | Debra Zanetti v. IKO Manufacturing Incorporated | civil | 06/05/2014 | oral argument
14-1159 | USA v. Oscar Gutierrez | criminal | 06/02/2014 | oral argument
14-1022 | Erika Langenbach v. Wal-Mart Stores, Incorporated | civil | 05/29/2014 | oral argument
14-1067 | Ernest Fenton v. Kelli Dudley | civil | 05/28/2014 | oral argument
14-1177 | USA v. Kenyon Walton | criminal | 05/28/2014 | oral argument
14-1053 | Suzan Gienapp v. Harbor Crest | civil | 05/27/2014 | oral argument
14-1024 | Sugiarto Halim v. Eric Holder, Jr. | agency | 05/23/2014 | oral argument
14-1128 | Leslie Klinger v. Conan Doyle Estate, Ltd. | civil | 05/22/2014 | oral argument
14-1124 | USA v. Paul Davis, Jr. | criminal | 05/21/2014 | oral argument
14-1103 | USA v. Raza Bokhari | criminal | 05/20/2014 | oral argument